==> tool-sql-2.6.0-pre3-sources.jar: io/ciera/tool/sql/ooaofooa/domain/BridgeSet.java <==
package io.ciera.tool.sql.ooaofooa.domain;


import io.ciera.runtime.summit.classes.IInstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.architecture.component.UtilityFunctionSet;
import io.ciera.tool.sql.ooaofooa.body.BridgeBodySet;
import io.ciera.tool.sql.ooaofooa.domain.BridgeParameterSet;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.ExternalEntitySet;
import io.ciera.tool.sql.ooaofooa.invocation.BridgeInvocationSet;
import io.ciera.tool.sql.ooaofooa.message.BridgeMessageSet;
import io.ciera.tool.sql.ooaofooa.value.BridgeValueSet;

import ooaofooa.datatypes.ActionDialect;
import ooaofooa.datatypes.ParseStatus;


public interface BridgeSet extends IInstanceSet<BridgeSet,Bridge> {

    // attributes
    public void setBrg_Typ( int m_Brg_Typ ) throws XtumlException;
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException;
    public void setSuc_Pars( ParseStatus m_Suc_Pars ) throws XtumlException;
    public void setAction_Semantics_internal( String m_Action_Semantics_internal ) throws XtumlException;
    public void setEE_ID( UniqueId ref_EE_ID ) throws XtumlException;
    public void setDialect( ActionDialect m_Dialect ) throws XtumlException;
    public void setName( String m_Name ) throws XtumlException;
    public void setAction_Semantics( String m_Action_Semantics ) throws XtumlException;
    public void setBrg_ID( UniqueId m_Brg_ID ) throws XtumlException;
    public void setDescrip( String m_Descrip ) throws XtumlException;
    public void setReturn_Dimensions( String m_Return_Dimensions ) throws XtumlException;


    // selections
    public BridgeMessageSet R1012_is_invoked_by_BridgeMessage() throws XtumlException;
    public ExternalEntitySet R19_provides_access_to_ExternalEntity() throws XtumlException;
    public DataTypeSet R20_return_value_defined_by_DataType() throws XtumlException;
    public BridgeParameterSet R21_is_part_of_BridgeParameter() throws XtumlException;
    public UtilityFunctionSet R4570_is_transformed_from_UtilityFunction() throws XtumlException;
    public DimensionsSet R50_return_value_may_have_Dimensions() throws XtumlException;
    public BridgeInvocationSet R674_BridgeInvocation() throws XtumlException;
    public BridgeBodySet R697_BridgeBody() throws XtumlException;
    public BridgeValueSet R828_BridgeValue() throws XtumlException;


}

==> tool-sql-2.7.0-sources.jar: io/ciera/tool/sql/ooaofooa/domain/BridgeSet.java <==
package io.ciera.tool.sql.ooaofooa.domain;


import io.ciera.runtime.summit.classes.IInstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.architecture.component.UtilityFunctionSet;
import io.ciera.tool.sql.ooaofooa.body.BridgeBodySet;
import io.ciera.tool.sql.ooaofooa.domain.BridgeParameterSet;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.ExternalEntitySet;
import io.ciera.tool.sql.ooaofooa.invocation.BridgeInvocationSet;
import io.ciera.tool.sql.ooaofooa.message.BridgeMessageSet;
import io.ciera.tool.sql.ooaofooa.value.BridgeValueSet;

import ooaofooa.datatypes.ActionDialect;
import ooaofooa.datatypes.ParseStatus;


public interface BridgeSet extends IInstanceSet<BridgeSet,Bridge> {

    // attributes
    public void setAction_Semantics_internal( String m_Action_Semantics_internal ) throws XtumlException;
    public void setName( String m_Name ) throws XtumlException;
    public void setSuc_Pars( ParseStatus m_Suc_Pars ) throws XtumlException;
    public void setReturn_Dimensions( String m_Return_Dimensions ) throws XtumlException;
    public void setDescrip( String m_Descrip ) throws XtumlException;
    public void setDialect( ActionDialect m_Dialect ) throws XtumlException;
    public void setAction_Semantics( String m_Action_Semantics ) throws XtumlException;
    public void setBrg_Typ( int m_Brg_Typ ) throws XtumlException;
    public void setBrg_ID( UniqueId m_Brg_ID ) throws XtumlException;
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException;
    public void setEE_ID( UniqueId ref_EE_ID ) throws XtumlException;


    // selections
    public BridgeMessageSet R1012_is_invoked_by_BridgeMessage() throws XtumlException;
    public ExternalEntitySet R19_provides_access_to_ExternalEntity() throws XtumlException;
    public DataTypeSet R20_return_value_defined_by_DataType() throws XtumlException;
    public BridgeParameterSet R21_is_part_of_BridgeParameter() throws XtumlException;
    public UtilityFunctionSet R4570_UtilityFunction() throws XtumlException;
    public DimensionsSet R50_return_value_may_have_Dimensions() throws XtumlException;
    public BridgeInvocationSet R674_BridgeInvocation() throws XtumlException;
    public BridgeBodySet R697_BridgeBody() throws XtumlException;
    public BridgeValueSet R828_BridgeValue() throws XtumlException;


}
